pub fn snapshot(key: &ScopeKey) -> BreakerSnapshotExpand description
Reads a breaker without touching it, for the dashboard. Not is_open, which clears an elapsed
cooldown as a side effect.
pub fn snapshot(key: &ScopeKey) -> BreakerSnapshotReads a breaker without touching it, for the dashboard. Not is_open, which clears an elapsed
cooldown as a side effect.